import React, { useState, useEffect, useRef } from 'react';
import ReactDOM from 'react-dom';
import {
  json,
  scaleLinear,
  scaleBand,
  max,
  select,
  axisLeft,
  axisBottom
} from 'd3';
const width = 960;
const height = 500;
const margin = {
  left:140,
  top: 50,
  right: 80,
  bottom: 50,
};

const listofSubgroup = ["Overall"," ","Male","Female","  ","Low Coverage","Mild Coverage","High Coverage","   ","No Education","< 5 years completed","5-9 years completed","10-11 years completed","12+ years completed","    ","Poorest","Second","Middle","Fourth","Richest"];


const App = () => {
  const [data, setData] = useState(null);
  const svgRef = useRef();
	 let tooltip2 = select("body").append("div")
    .attr("class", "tooltip2")
    .style("opacity", 0);

  const innerHeight = height - margin.top - margin.bottom;
  const innerWidth = width - margin.left - margin.right;
  useEffect(() => {
    json('subgroup.json').then((data) => {
      let cleanData = [];
      cleanData = data.map(d =>{
      if(d.subgroup_name === "All"){
      	d.subgroup_name = "Overall";
      }
        return d;
      }).filter(d => listofSubgroup.includes(d.subgroup_name))
      setData(cleanData);
    });
  }, []);
  
  useEffect(()=>{
    const svg = select(svgRef.current);
    const bar = svg.attr("width", width)
    		.attr("height", height)
      	.append("g")
    		.attr("transform",`translate(${margin.left},${margin.top})`);
    
        
    if(data){
      const xValue = d => d.data_value;
      const yValue = d => d.subgroup_name;

    
      const xScale = scaleLinear()
    		.domain([0, max(data, xValue)])
    		.range([0, innerWidth])
      
    	const yScale = scaleBand()
   	 		.domain(listofSubgroup)
    		.range([0,innerHeight])
      	.padding(0.1);;
     
      	
      
      let chart = bar.selectAll("rect").data(data);
      
      const fillRect = (d) =>{
        let darkSubgroup = ["Overall","Low Coverage","Mild Coverage","High Coverage","Poorest","Second","Middle","Fourth","Richest"]
        if(darkSubgroup.includes(d.subgroup_name))
          return "rgba(142,209,26)"
        else
          return "rgba(142,209,26,.5)"
      }
      chart.enter().append("rect")
      	.attr('y', d => yScale(yValue(d)))
      	.attr('width', d => {return xScale(xValue(d))})
      	.attr('height', yScale.bandwidth())
        .attr("fill", fillRect)
      	.on('mouseover', (i,d) => {
        			tooltip2.transition().duration(500).style("opacity", 1);
              tooltip2.html(`<b>${yValue(d)}</b><br/>${xValue(d)}`)
          		.style("left", xScale(xValue(d)) + margin.left  - 30+ "px")
          		.style("top", yScale(yValue(d))+ margin.top - 7 +"px");
              })
     .on('mouseout', ()=>{tooltip2.transition().duration(500).style("opacity", 0)});

     chart
          .enter().append("text")
          .text(d => xValue(d))
          .attr('x', d => xScale(d.data_value))
          .attr('y', d => yScale(yValue(d)) + (yScale.bandwidth()/2))
          .attr("font-family", "sans-serif")
          .attr("dy", ".3em")
          .attr("dx", ".3em")
          .attr("font-size", "11px")
          .attr("fill", "black")
      
      
      
      bar.append("g")
      	.attr("class","axis")
        .call(axisLeft(yScale).tickSize(0));
			
      bar.append("g")
      .attr("transform",`translate(0, ${innerHeight})`)
      	.attr("class","axis")
  			.call(axisBottom(xScale).ticks(5))
    }
    
   
   
      
  },[data])

  if (!data) {
    return <pre>Loading...</pre>;
  }
   
  
  return (
    <svg ref = {svgRef}></svg>
  ); 
};

ReactDOM.render(<App />, document.getElementById('root'));
